@@ -9,7 +9,7 @@ $(document).ready(function() {
 	$('#mainContentContainer').height('auto');
 
 	var $searchForm = $('#searchForm');
-	if!$searchForm.length)
+	if(!$searchForm.length)
 		return;
 
 	var $searchTextInput = $('#searchTextInput');
